# Implementation and Comparison of KMeans, KMneas++, DBSCAN

## Motivation
My motivation behind this project was to deepen my knowledge of clustering algorithms, which I first learnt in a university data mining course. We were assigned to implement the K-means and K-means++ algorithm. I really enjoyed this assignment, so I wanted to extend it further by also implementing the DBSCAN algorithm. 
Having done this project, my understanding of clusterings has definitely improved. I really started to see the strengths and weaknesses of each of the algorithms. In addition, I got more hands-on expereince with Numpy, as I avoided using Python for/while loops as much as possible to improve the effciency and runtime of the code. 
## How to install 

## How to use (console interface)

## How to use (in code)

## Demonstration of strengths and weaknesses of the implemented algorithms
